summaryrefslogtreecommitdiffstats
path: root/kpilot/kpilot/logFile.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/kpilot/logFile.cc')
-rw-r--r--kpilot/kpilot/logFile.cc32
1 files changed, 16 insertions, 16 deletions
diff --git a/kpilot/kpilot/logFile.cc b/kpilot/kpilot/logFile.cc
index b93b060ce..b7868bfda 100644
--- a/kpilot/kpilot/logFile.cc
+++ b/kpilot/kpilot/logFile.cc
@@ -30,9 +30,9 @@
#include "options.h"
-#include <qfile.h>
-#include <qtextstream.h>
-#include <qdatetime.h>
+#include <tqfile.h>
+#include <tqtextstream.h>
+#include <tqdatetime.h>
#include <pi-version.h>
@@ -45,7 +45,7 @@
#include "logFile.moc"
-LogFile::LogFile() : DCOPObject("LogIface"), QObject(), fOutfile(0L), fSyncing(false)
+LogFile::LogFile() : DCOPObject("LogIface"), TQObject(), fOutfile(0L), fSyncing(false)
{
FUNCTIONSETUP;
}
@@ -57,7 +57,7 @@ LogFile::LogFile() : DCOPObject("LogIface"), QObject(), fOutfile(0L), fSyncing(f
// If a sync is already running (something went wrong then!), close that old log
if (fSyncing) logEndSync();
- fOutfile = new QFile(KPilotSettings::logFileName());
+ fOutfile = new TQFile(KPilotSettings::logFileName());
if (!fOutfile || !fOutfile->open(IO_WriteOnly))
{
@@ -70,21 +70,21 @@ LogFile::LogFile() : DCOPObject("LogIface"), QObject(), fOutfile(0L), fSyncing(f
fSyncing = true;
fLogStream.setDevice(fOutfile);
- fLogStream<<(CSL1("KPilot HotSync log, %1").arg(QDateTime::currentDateTime().toString()))<<endl<<endl<<endl;
- fLogStream<<(CSL1("Version: KPilot %1").arg(QString::fromLatin1(KPILOT_VERSION)))<<endl;
+ fLogStream<<(CSL1("KPilot HotSync log, %1").arg(TQDateTime::currentDateTime().toString()))<<endl<<endl<<endl;
+ fLogStream<<(CSL1("Version: KPilot %1").arg(TQString::fromLatin1(KPILOT_VERSION)))<<endl;
fLogStream<<(CSL1("Version: pilot-link %1.%2.%3%4" )
.arg(PILOT_LINK_VERSION).arg(PILOT_LINK_MAJOR).arg(PILOT_LINK_MINOR)
#ifdef PILOT_LINK_PATCH
- .arg(QString::fromLatin1(PILOT_LINK_PATCH))
+ .arg(TQString::fromLatin1(PILOT_LINK_PATCH))
#else
- .arg(QString())
+ .arg(TQString())
#endif
)<<endl;
#ifdef KDE_VERSION_STRING
- fLogStream<<(CSL1("Version: KDE %1" ).arg(QString::fromLatin1(KDE_VERSION_STRING)) )<<endl;
+ fLogStream<<(CSL1("Version: KDE %1" ).arg(TQString::fromLatin1(KDE_VERSION_STRING)) )<<endl;
#endif
#ifdef QT_VERSION_STR
- fLogStream<<(CSL1("Version: Qt %1" ).arg(QString::fromLatin1(QT_VERSION_STR)) )<<endl;
+ fLogStream<<(CSL1("Version: Qt %1" ).arg(TQString::fromLatin1(QT_VERSION_STR)) )<<endl;
#endif
fLogStream<<endl<<endl;
@@ -102,27 +102,27 @@ LogFile::LogFile() : DCOPObject("LogIface"), QObject(), fOutfile(0L), fSyncing(f
}
}
/* DCOP */ ASYNC LogFile::logMessage(QString s)
{
addMessage(s);
}
/* DCOP */ ASYNC LogFile::logError(QString s)
{
addMessage(s);
}
/* DCOP */ ASYNC LogFile::logProgress(QString, int)
{
}
-void LogFile::addMessage(const QString & s)
+void LogFile::addMessage(const TQString & s)
{
FUNCTIONSETUP;
if ( fSyncing && !s.isEmpty() )
{
- fLogStream<<QTime::currentTime().toString()<<" "<<s<<endl;
+ fLogStream<<TQTime::currentTime().toString()<<" "<<s<<endl;
}
}
@@ -102,27 +102,27 @@ LogFile::LogFile() : DCOPObject("LogIface"), QObject(), fOutfile(0L), fSyncing(f
}
}
-/* DCOP */ ASYNC LogFile::logMessage(QString s)
+/* DCOP */ ASYNC LogFile::logMessage(TQString s)
{
addMessage(s);
@@ -102,27 +102,27 @@ LogFile::LogFile() : DCOPObject("LogIface"), QObject(), fOutfile(0L), fSyncing(f
addMessage(s);
}
-/* DCOP */ ASYNC LogFile::logError(QString s)
+/* DCOP */ ASYNC LogFile::logError(TQString s)
{
addMessage(s);
@@ -102,27 +102,27 @@ LogFile::LogFile() : DCOPObject("LogIface"), QObject(), fOutfile(0L), fSyncing(f
addMessage(s);
}
-/* DCOP */ ASYNC LogFile::logProgress(QString, int)
+/* DCOP */ ASYNC LogFile::logProgress(TQString, int)
{
}